PrefixCommonsAligner
====================

.. currentmodule:: bioregistry.align

.. autoclass:: PrefixCommonsAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PrefixCommonsAligner.curation_header
      ~PrefixCommonsAligner.include_new
      ~PrefixCommonsAligner.key

   .. rubric:: Methods Summary

   .. autosummary::

      ~PrefixCommonsAligner.get_curation_row
      ~PrefixCommonsAligner.getter

   .. rubric:: Attributes Documentation

   .. autoattribute:: curation_header
   .. autoattribute:: include_new
   .. autoattribute:: key

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: getter
